pub struct MessageHistory {
tree: Tree,
encryption: Option<StorageEncryption>,
}Expand description
A MessageStore implementation using sled for storage.
Fields
tree: Treeencryption: Option<StorageEncryption>Implementations
Sourceimpl MessageHistory
impl MessageHistory
Sourcefn get_conversation_id(p1: &PeerId, p2: &PeerId) -> Vec<u8> ⓘ
fn get_conversation_id(p1: &PeerId, p2: &PeerId) -> Vec<u8> ⓘ
Creates a canonical, ordered conversation ID from two PeerIds.
This ensures that the conversation ID is always the same regardless of
the order of the PeerIds.
Sourcefn make_composite_key(
conversation_id: &[u8],
timestamp: i64,
nonce: u64,
) -> Vec<u8> ⓘ
fn make_composite_key( conversation_id: &[u8], timestamp: i64, nonce: u64, ) -> Vec<u8> ⓘ
Creates a composite key for storing a message, based on conversation ID, timestamp, and nonce.
Sourcefn serialize_message(&self, msg: &Message) -> Result<Vec<u8>>
fn serialize_message(&self, msg: &Message) -> Result<Vec<u8>>
Serializes a Message and encrypts it if encryption is enabled.
Sourcefn deserialize_message(&self, data: &[u8]) -> Result<Message>
fn deserialize_message(&self, data: &[u8]) -> Result<Message>
Decrypts and deserializes a Message.